module BinectImporter
    class DropboxImporter
        IMPORTER_TYPE = "dropbox"

        def initialize(user)
            @user = user
        end

        def import
            client = self.class.get_dropbox_client(@user)

            # Load all files in root directory:
            client.metadata("/")["contents"].each do |f|
                # Only handle pdf files
                next if f["is_dir"] == true
                next if f["mime_type"] != "application/pdf"

                file_path = f["path"]

                Rails.logger.info "Import PDF: Load file with path: #{file_path}"
                file = client.get_file(file_path)
                Rails.logger.info "Import PDF: ready"

                # Call external block that will handle the file.
                is_success = yield( file, File.basename( file_path ), f["mime_type"], f["bytes"] )

                if is_success
                    # Remove file
                    Rails.logger.info "Remove file: #{file_path}"
                    client.file_delete(file_path)
                end
            end
        end

        def export(file_data, file_path, mime_type)
            Rails.logger.info "Exporting file '#{file_path}'.."
        end

        def self.get_dropbox_client(user)
            return nil if user.nil?
            dropbox_data = user.authenticated_importers.select { |importer_hash| importer_hash[:type] == DropboxImporter::IMPORTER_TYPE }
            return nil if dropbox_data.nil? || dropbox_data.first.nil? || dropbox_data.first[:access_token].nil?

            access_token = dropbox_data.first[:access_token]
            DropboxClient.new(access_token)
        end
    end
end
